# v0.3.0 - 2023/05/04

- Update cython bindings for modern python versions
- Added `pointwise_sph_grads` function

# v0.2.0 - 2020/02/26

- Added tensorflow operation support in python (`fsph.tf_ops`) on the CPU and GPU

# v0.1

- Basic functionality
